@@ -1,7 +1,7 @@
 """
 Type annotations for machinelearning service client waiters.
 
-[Open documentation](./waiters.md)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/waiters.html)
 
 Usage::
 
@@ -45,11 +45,12 @@ __all__ = (
 
 class BatchPredictionAvailableWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/machinelearning.html#MachineLearning.Waiter.batch_prediction_available)[Show boto3-stubs documentation](./waiters.md#batchpredictionavailablewaiter)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/machinelearning.html#MachineLearning.Waiter.batch_prediction_available)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/waiters.html#batchpredictionavailablewaiter)
     """
 
     def wait(
         self,
+        *,
         FilterVariable: BatchPredictionFilterVariableType = None,
         EQ: str = None,
         GT: str = None,
@@ -61,21 +62,22 @@ class BatchPredictionAvailableWaiter(Boto3Waiter):
         SortOrder: SortOrderType = None,
         NextToken: str = None,
         Limit: int = None,
-        WaiterConfig: WaiterConfigTypeDef = None,
+        WaiterConfig: WaiterConfigTypeDef = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/machinelearning.html#MachineLearning.Waiter.BatchPredictionAvailableWaiter)
-        [Show boto3-stubs documentation](./waiters.md#batchpredictionavailable)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/machinelearning.html#MachineLearning.Waiter.BatchPredictionAvailableWaiter)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/waiters.html#batchpredictionavailable)
         """
 
 
 class DataSourceAvailableWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/machinelearning.html#MachineLearning.Waiter.data_source_available)[Show boto3-stubs documentation](./waiters.md#datasourceavailablewaiter)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/machinelearning.html#MachineLearning.Waiter.data_source_available)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/waiters.html#datasourceavailablewaiter)
     """
 
     def wait(
         self,
+        *,
         FilterVariable: DataSourceFilterVariableType = None,
         EQ: str = None,
         GT: str = None,
@@ -87,21 +89,22 @@ class DataSourceAvailableWaiter(Boto3Waiter):
         SortOrder: SortOrderType = None,
         NextToken: str = None,
         Limit: int = None,
-        WaiterConfig: WaiterConfigTypeDef = None,
+        WaiterConfig: WaiterConfigTypeDef = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/machinelearning.html#MachineLearning.Waiter.DataSourceAvailableWaiter)
-        [Show boto3-stubs documentation](./waiters.md#datasourceavailable)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/machinelearning.html#MachineLearning.Waiter.DataSourceAvailableWaiter)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/waiters.html#datasourceavailable)
         """
 
 
 class EvaluationAvailableWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/machinelearning.html#MachineLearning.Waiter.evaluation_available)[Show boto3-stubs documentation](./waiters.md#evaluationavailablewaiter)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/machinelearning.html#MachineLearning.Waiter.evaluation_available)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/waiters.html#evaluationavailablewaiter)
     """
 
     def wait(
         self,
+        *,
         FilterVariable: EvaluationFilterVariableType = None,
         EQ: str = None,
         GT: str = None,
@@ -113,21 +116,22 @@ class EvaluationAvailableWaiter(Boto3Waiter):
         SortOrder: SortOrderType = None,
         NextToken: str = None,
         Limit: int = None,
-        WaiterConfig: WaiterConfigTypeDef = None,
+        WaiterConfig: WaiterConfigTypeDef = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/machinelearning.html#MachineLearning.Waiter.EvaluationAvailableWaiter)
-        [Show boto3-stubs documentation](./waiters.md#evaluationavailable)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/machinelearning.html#MachineLearning.Waiter.EvaluationAvailableWaiter)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/waiters.html#evaluationavailable)
         """
 
 
 class MLModelAvailableWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/machinelearning.html#MachineLearning.Waiter.ml_model_available)[Show boto3-stubs documentation](./waiters.md#mlmodelavailablewaiter)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/machinelearning.html#MachineLearning.Waiter.ml_model_available)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/waiters.html#mlmodelavailablewaiter)
     """
 
     def wait(
         self,
+        *,
         FilterVariable: MLModelFilterVariableType = None,
         EQ: str = None,
         GT: str = None,
@@ -139,9 +143,9 @@ class MLModelAvailableWaiter(Boto3Waiter):
         SortOrder: SortOrderType = None,
         NextToken: str = None,
         Limit: int = None,
-        WaiterConfig: WaiterConfigTypeDef = None,
+        WaiterConfig: WaiterConfigTypeDef = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/machinelearning.html#MachineLearning.Waiter.MLModelAvailableWaiter)
-        [Show boto3-stubs documentation](./waiters.md#mlmodelavailable)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/machinelearning.html#MachineLearning.Waiter.MLModelAvailableWaiter)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/waiters.html#mlmodelavailable)
         """
